"""
A library of clients for the main resources of the GiantBomb API
http://www.giantbomb.com/api/documentation#toc-0-1
"""
from pybomb.clients.games_client import GamesClient
from pybomb.clients.game_client import GameClient

# Platform ID's
PS1 = 22
PS2 = 19
PS3 = 35
PS4 = 146

XBOX = 32
XBOX_360 = 20
XBOX_ONE = 145

MAC = 17
PC = 94
